@@ -1,7 +1,7 @@
 import pytest
+from demoproject.demoapp.models import DemoModel, DemoModelField, DemoRelated
 
-from adminfilters.filters import TextFieldFilter, ForeignKeyFieldFilter
-from demoproject.demoapp.models import DemoModelField, DemoRelated, DemoModel
+from adminfilters.filters import ForeignKeyFieldFilter, TextFieldFilter
 
 DATA = {
     "nullable": "bbbb",
